psychopy_ext.exp.ThickShapeStim — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.ThickShapeStim

class `psychopy_ext.exp.` `ThickShapeStim`(win, units='', lineWidth=0.01, lineColor=(1.0, 1.0, 1.0), lineColorSpace='rgb', fillColor=None, fillColorSpace='rgb', vertices=((-0.5, 0), (0, 0.5), (0.5, 0)), closeShape=True, pos=(0, 0), size=1, ori=0.0, opacity=1.0, contrast=1.0, depth=0, interpolate=True, lineRGB=None, fillRGB=None, name='', autoLog=True)

  Parameters: |

  lineWidth : int (or float?)
    specifying the line width in units of your choice
  vertices : a list of lists or a numpy array (Nx2)
    specifying xy positions of each vertex
  closeShape : True or False
    Do you want the last vertex to be automatically connected to the first?
  interpolate : True or False
    If True the edge of the line will be antialiased.
  `__init__`(win, units='', lineWidth=0.01, lineColor=(1.0, 1.0, 1.0), lineColorSpace='rgb', fillColor=None, fillColorSpace='rgb', vertices=((-0.5, 0), (0, 0.5), (0.5, 0)), closeShape=True, pos=(0, 0), size=1, ori=0.0, opacity=1.0, contrast=1.0, depth=0, interpolate=True, lineRGB=None, fillRGB=None, name='', autoLog=True)

    Parameters: | lineWidth : int (or float?) specifying the line width in units of your choice vertices : a list of lists or a numpy array (Nx2) specifying xy positions of each vertex closeShape : True or False Do you want the last vertex to be automatically connected to the first? interpolate : True or False If True the edge of the line will be antialiased.

  Methods

  `__init__`(win[, units, lineWidth, lineColor, ...]) |
  Parameters: |
  `contains`(x[, y, units]) | Determines if a point x,y is inside the extent of the stimulus.
  `draw`() |
  `overlaps`(polygon) | Determines if this stimulus intersects another one.
  `setAutoDraw`(value[, log]) | Usually you can use ‘stim.attribute = value’ syntax instead,
  `setAutoLog`([value]) | Usually you can use ‘stim.attribute = value’ syntax instead,
  `setColor`(color[, colorSpace, operation]) | For ShapeStim use `lineColor()` or
  `setContrast`(newContrast[, operation, log]) | Usually you can use ‘stim.attribute = value’ syntax instead,
  `setDKL`(newDKL[, operation]) | DEPRECATED since v1.60.05: Please use the color attribute
  `setDepth`(newDepth[, operation, log]) | Usually you can use ‘stim.attribute = value’ syntax instead,
  `setFillColor`(color[, colorSpace, operation, log]) | Sets the color of the shape fill.
  `setFillRGB`(value[, operation]) | DEPRECATED since v1.60.05: Please use `setFillColor()`
  `setLMS`(newLMS[, operation]) | DEPRECATED since v1.60.05: Please use the color attribute
  `setLineColor`(color[, colorSpace, operation, log]) | Sets the color of the shape edge.
  `setLineRGB`(value[, operation]) | DEPRECATED since v1.60.05: Please use `setLineColor()`
  `setOpacity`(newOpacity[, operation, log]) | Usually you can use ‘stim.attribute = value’ syntax instead,
  `setOri`(newOri) |
  `setPos`(newPos) |
  `setRGB`(newRGB[, operation]) | DEPRECATED since v1.60.05: Please use the color attribute
  `setSize`(value[, operation, log]) | Sets the size of the shape.
  `setUseShaders`([value]) | Usually you can use ‘stim.attribute = value’ syntax instead,
  `setVertices`([value]) |